/* $Id: et6000.h,v 1.6 1998/11/24 18:45:21 marcus Exp $
******************************************************************************

   Tseng ET6000 chipset driver includes

   Copyright (C) 1997		Jim Ursetto	[jim.ursetto@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

/*
**	This code is derived from the following source of information:
**
**	[1]	et4000.h by Andreas Vogler
**	[2]	et6k_regs.h by Jaromir Koutek
**	[3] Prerelease VGADOC5 by Finn Thoegersen
*/

#ifndef _Tseng_et6000_h
#define	_Tseng_et6000_h

#include <IBM/vga.h>

/* These are used to enable/disable Tseng-specific extensions. */
#define HERC_CMPT          0x3bf /* Hercules compatibility register */
#define DMODE_CTRL         0x3d8 /* Display mode control register?  */

/* ATC */ 
	#define ATC_MISC	0x16
		#define AR16_DISBL_OVERSCANREG	0x01
		#define AR16_DISBL_PLRAM	0x02
		#define AR16_HIRES_MASK		0x30 /* diff.meaning for W32!*/
		#define AR16_W32_HICOLOR	0x20
		#define AR16_HIRES_8BIT		0x20
		#define AR16_HIRES_16BIT	0x30
		#define AR16_ENBL_2BYTE		0x40
		#define AR16_DISBL_EGAPAL	0x80
	#define ATC_MISC1	0x17
		#define AR17_REDEFINE_ATR	0x80

/* SEQ */
	#define SEQ_TSCTRL	0x06
		#define SR06_WIDTH_MASK	0x06
	#define SEQ_TSAUX	0x07
		#define SR07_DIV4	0x01
		#define SR07_EQ_CLKS	0x02
		#define SR07_SCALE_MASK	0x14	/* ET4000W32x ONLY !!! */
		#define SR07_ROM_MASK	0x28
		#define SR07_DIV2	0x40
		#define SR07_ENBL_VGA	0x80

/* Microchannel Video Subsystem Enable Register */
#define MVSE_REG	0x3C3

/* Extended Bank Registers */
#define EXT_BANK	0x3CB		/* W32 ONLY !! */

/* Segment Select */
#define SEG_SELECT	0x3CD
		#define SGS_WRITE_MASK	0x0F
		#define SGS_READ_MASK	0xF0

/* CRT color */
	#define CRT_LFB		0x30	/* Linear frame buffer; W32 ??? */
	#define CRT_GENERAL	0x31
		#define CR31_CLK_MASK	0xC0
	#define CRT_RASCAS	0x32 
		#define CR32_INTERLEAVE	0x80
	#define CRT_EXT_ADDR	0x33
		#define CR33_DISPSTART_MASK	0x0F
		#define CR33_CURSORSTART_MASK	0xF0
	#define CRT_CCR		0x34
		#define CR34_CLK_SEL2	0x02
	#define CRT_OVRFLW_V	0x35
		#define CR35_VBLANKSTART_B10	0x01
		#define CR35_VTOTAL_B10	0x02
		#define CR35_VDISPLAYEND_B10	0x04
		#define CR35_VSYNCSTART_B10	0x08
		#define CR35_LINECOMPARE_B10	0x10
		#define CR35_INTERLACE		0x80
	#define CRT_VIDEO_CFG1	0x36
	#define CRT_VIDEO_CFG2	0x37
	#define CRT_OVRFLW_H	0x3F
		#define CR3F_HTOTAL_B8	0x01
		#define CR3F_HBLANKSTART_B8	0x04
		#define CR3F_HSYNCSTART_B8	0x10
                #define CR3F_LOGICALWIDTH_B9    0x40  /* et6000 */
                #define CR3F_LOGICALWIDTH_B8	0x80

/* AT&T mode control */
#define ATT_CTRL	0x3DE

/* Display mode control */
#define DISPLAY_MODE	0x3D8
#define HERC_CMPT       0x3bf /* Hercules compatibility register? */

/* CRTCB/Sprite register at 0x21xA; it is usually at 0x217A */
#define SPRITEI		0x217A
#define SPRITED		0x217B

#define PCI_REVISION        0x08 /* Revision of chip */
#define PCI_MMCONTROL       0x40 /* Memory map control register */
 #define PCI40_LINEARMAP    0x01  /* enable System linear mapping; must enable PCI40_MEMRELOC too! */
 #define PCI40_MEMMAPREG    0x02  /* enable Memory mapped (io) registers */
 #define PCI40_MMU          0x04  /* enable MMU */
 #define PCI40_MEMRELOC     0x08  /* enable Memory relocation */
#define PCI_MEMCONF         0x45 /* Memory configuration register */
 #define PCI45_DRAMSIZE     0x03  /* for DRAM: 0 -> 1MB, 1-> 2MB, 2-> 4MB */
 #define PCI45_MDRAMDBL     0x04  /* if set, doubles size of MDRAM :-) */
#define PCI_CRTFEATURE      0x46 /* CRT display feature register */
 #define PCI46_SPEN         0x01  /* enable HW cursor */
 #define PCI46_LTWO         0x02  /* enable Display list */
 #define PCI46_FCDS         0x40  /* enable Feature connector */
 #define PCI46_XDDE         0x80  /* 1 - Extended Express bus address <- don't know what this means */
#define PCI_TSTSETUP        0x47 /* Test setup register */
 #define PCI47_RFN          0x07 /* MDRAM: size of memory in 32kB: (n+1)*8 */
#define PCI_VIDCTRL1        0x58 /* Video Control 1 */
 #define PCI58_BPP16        0x02  /* in 16bpp mode, set is 16 bpp and clear is 15 bpp */
#define PCI_CRTDACri        0x67 /* CRT DAC read index */
 #define PCI67_IDX          0x0f  /* read index mask */
 #define PCI67_RES          0xf0  /* read index reserved */
#define PCI_CRTDACwi        0x68 /* CRT DAC write index */
 #define PCI68_IDX          0x0f  /* write index mask */
 #define PCI68_RES          0xf0  /* write index reserved */
#define PCI_CRTDAC          0x69 /* CRT DAC data */
 #define PCI69_SPRITE_COLOR 0x09  /* Sprite color register index in CRT DAC register */
#define PCI_SPRITE_SIZEX    0x82 /* sprite horizontal preset - x size; bits: 0-5 */
#define PCI_SPRITE_SIZEY    0x83 /* sprite vertical preset - y size; bits: 0-5 */
#define PCI_SPRITE_POSX     0x84 /* sprite horizontal position - x; bits: 0-11 */
#define PCI_SPRITE_POSY     0x86 /* sprite vertical position - y; bits: 0-11 */

/* Kernels <= 2.0.27 do not define this device in pci.h. */
#ifndef PCI_DEVICE_ID_TSENG_ET6000
#  define PCI_DEVICE_ID_TSENG_ET6000 0x3208
#endif

extern struct io_region et6000_pci_io;

#endif	/* #ifndef _Tseng_et6000_h */
